pub struct AutomatedBufferStats {
pub current_id: BeltBufferId,
pub live_buffers: usize,
pub current_size: Option<BufferAddress>,
}Expand description
Statistics about current buffers.
Fields
current_id: BeltBufferIdID of the current buffer. Each new buffer gets a sequentially higher number, so can be used to figure out how many buffers were made in total.
live_buffers: usizeTotal number of buffers that are in the queue or currently in flight.
current_size: Option<BufferAddress>Current size of the underlying buffer.